from numpy.testing.utils import assert_equal, assert_raises
from nose import with_setup
from nose.plugins.attrib import attr

from brian2 import *
from brian2.devices.device import reinit_devices
from brian2.core.network import schedule_propagation_offset
from brian2.tests.utils import assert_allclose


@attr('codegen-independent')
def test_poissoninput_errors():
    # Targeting non-existing variable
    G = NeuronGroup(10, '''x : volt
                           y : 1''')
    assert_raises(KeyError, lambda: PoissonInput(G, 'z', 100, 100*Hz, weight=1.0))

    # Incorrect units
    assert_raises(DimensionMismatchError,
                  lambda: PoissonInput(G, 'x', 100, 100*Hz, weight=1.0))
    assert_raises(DimensionMismatchError,
                  lambda: PoissonInput(G, 'y', 100, 100*Hz, weight=1.0*volt))

    # dt change
    old_dt = defaultclock.dt
    inp = PoissonInput(G, 'x', 100, 100*Hz, weight=1*volt)
    defaultclock.dt = 2 * old_dt
    net = Network(collect())
    assert_raises(NotImplementedError, lambda: net.run(0*ms))
    defaultclock.dt = old_dt


if __name__ == '__main__':
    test_poissoninput()
    reinit_devices()
    test_poissoninput_errors()
    test_poissoninput_refractory()
